@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2010-2012 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2010-2013 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -40,6 +40,7 @@
  */
 
 namespace TheSeer\fDOM {
+    use TheSeer\fDOM\CSS\Translator;
 
     /**
      * fDOMDocument extension to PHP's DOMDocument.
@@ -85,10 +86,10 @@ namespace TheSeer\fDOM {
             libxml_use_internal_errors(TRUE);
             $rc = parent::__construct($version, $encoding);
 
-            $this->registerNodeClass('\DOMDocument', get_called_class());
-            $this->registerNodeClass('\DOMNode', 'TheSeer\fDOM\fDOMNode');
-            $this->registerNodeClass('\DOMElement', 'TheSeer\fDOM\fDOMElement');
-            $this->registerNodeClass('\DOMDocumentFragment', 'TheSeer\fDOM\fDOMDocumentFragment');
+            $this->registerNodeClass('DOMDocument', get_called_class());
+            $this->registerNodeClass('DOMNode', 'TheSeer\fDOM\fDOMNode');
+            $this->registerNodeClass('DOMElement', 'TheSeer\fDOM\fDOMElement');
+            $this->registerNodeClass('DOMDocumentFragment', 'TheSeer\fDOM\fDOMDocumentFragment');
 
             return $rc;
         }
@@ -96,13 +97,17 @@ namespace TheSeer\fDOM {
         /**
          * Reset XPath object so the clone gets a new instance when needed
          */
-        function __clone() {
+        public function __clone() {
             $this->xp = new fDOMXPath($this);
             foreach($this->prefixes as $prefix => $uri) {
                 $this->xp->registerNamespace($prefix, $uri);
             }
         }
 
+        public function __toString() {
+            return $this->C14N();
+        }
+
         /**
          * Set Stream context options
          *
@@ -375,6 +380,24 @@ namespace TheSeer\fDOM {
             return $this->xp->prepare($xpath, $valueMap);
         }
 
+        /**
+         * Use a CSS Level 3 Selector string to query select nodes
+         *
+         * @param string   $selector A CSS Level 3 Selector string
+         * @param \DOMNode $ctx
+         * @param bool     $registerNodeNS
+         *
+         * @return \DOMNodeList
+         */
+        public function select($selector, \DOMNode $ctx = NULL, $registerNodeNS = TRUE) {
+            $translator = new Translator();
+            $xpath = $translator->translate($selector);
+            if ($ctx != NULL) {
+                $xpath = '.' . $xpath;
+            }
+            return $this->query($xpath, $ctx, $registerNodeNS);
+        }
+
         /**
          * Forward to DOMXPath->registerNamespace()
          *
@@ -510,7 +533,7 @@ namespace TheSeer\fDOM {
             }
             return $this->isSameNode($node->ownerDocument);
         }
-        
+
         /**
          * Create a new element and append it as documentElement
          *
@@ -542,4 +565,4 @@ namespace TheSeer\fDOM {
 
     } // fDOMDocument
 
-}
\ No newline at end of file
+}
